Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(55)

Unified Diff: webkit/tools/test_shell/test_shell.h

Issue 21192: Add support for the "repaint" layout tests (LayoutTests/fast/repaint/*), whic... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/tools/test_shell/test_shell.h
===================================================================
--- webkit/tools/test_shell/test_shell.h (revision 9433)
+++ webkit/tools/test_shell/test_shell.h (working copy)
@@ -209,9 +209,9 @@
// the flags set.
static void Dump(TestShell* shell);
// Writes the image captured from the given web frame to the given file.
// The returned string is the ASCII-ized MD5 sum of the image.
- static std::string DumpImage(WebFrame* web_frame,
+ static std::string DumpImage(WebViewHost* web_view_host,
const std::wstring& file_name);
static void ResetWebPreferences();
@@ -209,9 +209,9 @@
// the flags set.
static void Dump(TestShell* shell);
- // Writes the image captured from the given web frame to the given file.
+ // Writes the image captured from the given web view to the given file.
// The returned string is the ASCII-ized MD5 sum of the image.

Powered by Google App Engine
This is Rietveld 408576698